CodeGraphMeta class
Metadatos de tiempo de compilación que envuelven un CodeGraph en un documento
publicado. generatedAt es suministrado por el llamador para que el contrato
permanezca libre de reloj (puro).
Constructors
- CodeGraphMeta({required String schemaVersion, required String package, required String generatedAt, required String inputsFingerprint, required String root, int skippedFiles = 0, bool resolved = false, int resolvedFiles = 0, int unresolvedFiles = 0})
-
const
-
CodeGraphMeta.fromJson(Map<
String, Object?> json) -
factory
Properties
- generatedAt → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputsFingerprint → String
-
final
- package → String
-
final
- resolved → bool
-
final
- resolvedFiles → int
-
final
- root → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String
-
final
- skippedFiles → int
-
final
- unresolvedFiles → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited